@@ -295,17 +295,18 @@ def test_localcommands_run(
         fake_cli_config):
     commands = LocalCommands(fake_cli_config)
 
-    commands.run()
+    commands.run(host='127.0.0.1', port='5000')
 
     run_env = os.environ.copy()
     run_env['FLASK_ENV'] = 'development'
     expected_calls = [
         call([
-            'pipenv', 'run', 'celery', 'worker', '--app', 'invenio_app.celery'
+            'pipenv', 'run', 'celery', '--app', 'invenio_app.celery', 'worker'
         ]),
         call([
             'pipenv', 'run', 'invenio', 'run', '--cert',
-            'docker/nginx/test.crt', '--key', 'docker/nginx/test.key'
+            'docker/nginx/test.crt', '--key', 'docker/nginx/test.key',
+            '--host', '127.0.0.1', '--port', '5000'
         ], env=run_env),
         call().wait()
     ]
